==> MXM_1.3.1.tar.gz: MXM/R/internaliamb.binombs.R <==
######## Internal for binomial/logistic regression
internaliamb.binombs <- function(target, dataset, threshold, wei, p, heavy = FALSE, robust = FALSE) {
  if ( !is.null(dataset) |  p > 0 ) {
    if ( p > 1 ) {
      if ( !heavy ) {
        ini <- glm( target ~.,  data = dataset, family = binomial(logit), weights = wei, y = FALSE, model = FALSE )
        tab <- drop1( ini, test = "Chisq" )
        dof <- tab[-1, 1]
        stat <- tab[-1, 4]
        
      } else {
        ci_test <- "testIndSpeedglm"
        ini <- speedglm::speedglm( target ~.,  data = dataset, family = binomial(logit), weights = wei )
        dofini <- length( coef(ini) )
        stat <- dof <- numeric(p)
        for (i in 1:p) {
          mod <- speedglm::speedglm( target ~.,  data = dataset[, -i, drop = FALSE], family = binomial(logit), weights = wei )
          stat[i] <- mod$deviance - ini$deviance
          dof[i] <- dofini - length( coef(mod) ) 
        }
      }	
    } else {
      if ( !heavy ) {
        ini <- glm( target ~.,  data = dataset, family = binomial(logit), weights = wei, y = FALSE, model = FALSE )
        mod0 <- glm(target ~ 1, family = binomial(logit), weights = wei, y = FALSE, model = FALSE)
      } else {
        ini <- speedglm::speedglm( target ~.,  data = dataset, family = binomial(logit), weights = wei )
        mod0 <- speedglm::speedglm( target ~ 1,  data = dataset, family = binomial(logit), weights = wei )
      } 
      stat <- mod0$deviance - ini$deviance
      dof <- length( coef(ini) ) - 1
    }
    
    mat <- cbind(1:p, pchisq( stat, dof, lower.tail = FALSE, log.p = TRUE), stat )
    colnames(mat) <- c("variable", "log.p-values", "statistic" )
    rownames(mat) <- 1:p  
    
    info <- matrix( c(0, -10, -10) , ncol = 3 )
    sel <- which( mat[, 2] > threshold ) 
    
    if ( length(sel) == 0 ) {
      final <- ini 
      
    } else {
      
      info <- mat[sel, , drop = FALSE]
      mat <- mat[-sel, , drop = FALSE] 
      dat <- dataset[, -sel, drop = FALSE] 
      
      if ( p - length(sel) == 0 ) {
        final <- "No variables were selected"
        mat <- matrix(nrow = 0, ncol = 3)
      } else if ( p - length(sel) == 1 ) {
        if ( !heavy ) {
          mod1 <- glm(target ~., data = dat, family = binomial(logit), weights = wei, y = FALSE, model = FALSE)
          mod0 <- glm(target ~ 1, family = binomial(logit), weights = wei, y = FALSE, model = FALSE)
        } else  {
          mod1 <- speedglm::speedglm( target ~ .,  data = dat, family = binomial(logit), weights = wei )
          mod0 <- speedglm::speedglm( target ~ 1,  data = dat, family = binomial(logit), weights = wei )
        }  
        stat <- abs( mod1$deviance - mod0$deviance )
        pval <- pchisq( stat, length( coef(mod1) ) - 1, lower.tail = FALSE, log.p = TRUE)
        if (pval > threshold ) {
          final <- "No variables were selected"
          mat <- matrix(nrow = 0, ncol = 3)
        } else final <- mod1
      } else {
        if ( !heavy ) {
          final <- glm(target ~., data = dat, family = poisson(log), weights = wei, y = FALSE, model = FALSE)
        } else  final <- speedglm::speedglm( target ~ .,  data = dat, family = poisson(log), weights = wei )
      }
    }
    info <- info[ info[, 1] > 0, , drop = FALSE]
    
  } else { 
    info <- NULL  
    mat <- matrix(nrow = 0, ncol = 3)
    final <- "No variables were selected"
  } 
  
  list(info = info, mat = mat, final = final) 
}

==> MXM_1.4.3.tar.gz: MXM/R/internaliamb.binombs.R <==
######## Internal for binomial/logistic regression
internaliamb.binombs <- function(target, dataset, threshold, wei, p) {
  if ( !is.null(dataset) |  p > 0 ) {
    if ( p > 1 ) {
      ini <- glm( target ~.,  data = dataset, family = binomial(logit), weights = wei, y = FALSE, model = FALSE )
      tab <- drop1( ini, test = "Chisq" )
      dof <- tab[-1, 1]
      stat <- tab[-1, 4]

    } else {
      ini <- glm( target ~.,  data = dataset, family = binomial(logit), weights = wei, y = FALSE, model = FALSE )
      mod0 <- glm(target ~ 1, family = binomial(logit), weights = wei, y = FALSE, model = FALSE)
      stat <- mod0$deviance - ini$deviance
      dof <- length( coef(ini) ) - 1
    }
    
    mat <- cbind(1:p, pchisq( stat, dof, lower.tail = FALSE, log.p = TRUE), stat )
    colnames(mat) <- c("variable", "log.p-values", "statistic" )
    rownames(mat) <- 1:p  
    info <- matrix( c(0, -10, -10) , ncol = 3 )
    sel <- which( mat[, 2] > threshold ) 
    
    if ( length(sel) == 0 ) {
      final <- ini 
      
    } else {
      
      info <- mat[sel, , drop = FALSE]
      mat <- mat[-sel, , drop = FALSE] 
      dat <- dataset[, -sel, drop = FALSE] 
      
      if ( p - length(sel) == 0 ) {
        final <- "No variables were selected"
        mat <- matrix(nrow = 0, ncol = 3)
      } else if ( p - length(sel) == 1 ) {
        mod1 <- glm(target ~., data = dat, family = binomial(logit), weights = wei, y = FALSE, model = FALSE)
        mod0 <- glm(target ~ 1, family = binomial(logit), weights = wei, y = FALSE, model = FALSE)
        stat <- abs( mod1$deviance - mod0$deviance )
        pval <- pchisq( stat, length( coef(mod1) ) - 1, lower.tail = FALSE, log.p = TRUE)
        if (pval > threshold ) {
          final <- "No variables were selected"
          mat <- matrix(nrow = 0, ncol = 3)
        } else final <- mod1
      } else {
        final <- glm(target ~., data = dat, family = poisson(log), weights = wei, y = FALSE, model = FALSE)
      }
    }
    info <- info[ info[, 1] > 0, , drop = FALSE]
    
  } else { 
    info <- NULL  
    mat <- matrix(nrow = 0, ncol = 3)
    final <- "No variables were selected"
  } 
  
  list(info = info, mat = mat, final = final) 
}
